'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PayslipPropTypes = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _dateHolidays = require('date-holidays');

var _dateHolidays2 = _interopRequireDefault(_dateHolidays);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_moment2.default.locale('fr', {
  months: ['Janvier', 'Février', 'Mars', 'Avril', 'Mai', 'Juin', 'Juillet', 'Août', 'Septembre', 'Octobre', 'Novembre', 'Décembre'],
  weekdaysShort: ['D', 'L', 'M', 'M', 'J', 'V', 'S'],
  weekdaysMin: ['Di', 'Lu', 'Ma', 'Me', 'Je', 'Ve', 'Sa']
});

var hd = new _dateHolidays2.default();
hd.init('FR');

function getDayOff(startDate, endDate) {
  if (!startDate || !endDate) {
    return {
      cp: '-',
      cpPrevious: '-'
    };
  }

  var DAYOFF_BY_MONTH = 2.08;
  var startDateUTC = _moment2.default.utc(startDate);
  var endDateUTC = _moment2.default.utc(endDate);

  var startDay = startDateUTC.date();
  var dayInMonth = startDateUTC.daysInMonth();

  var firstMonthDayOff = (dayInMonth - startDay + 1) / dayInMonth * DAYOFF_BY_MONTH;

  var cp = firstMonthDayOff;
  var cpPrevious = 0;

  while (startDateUTC < endDateUTC) {
    startDateUTC.add(1, 'month');
    cp += DAYOFF_BY_MONTH;

    if (startDateUTC.month() === 4) {
      cpPrevious = cp;
      cp = 0;
    }
  }

  return {
    cp: cp.toFixed(2),
    cpPrevious: cpPrevious.toFixed(2)
  };
}

function isNumber(n) {
  return !isNaN(parseFloat(n)) && isFinite(n);
}

function getValue() {
  for (var _len = arguments.length, values = Array(_len), _key = 0; _key < _len; _key++) {
    values[_key] = arguments[_key];
  }

  if (!values.some(isNumber)) {
    return '-';
  }

  return Math.abs(parseFloat(values.reduce(function (a, b) {
    a = Math.abs(parseFloat(a || 0));
    b = Math.abs(parseFloat(b || 0));

    return a + b;
  }))).toFixed(2);
}

function formatDate(_ref) {
  var date = _ref.date,
      _ref$startOfMonth = _ref.startOfMonth,
      startOfMonth = _ref$startOfMonth === undefined ? false : _ref$startOfMonth,
      _ref$endOfMonth = _ref.endOfMonth,
      endOfMonth = _ref$endOfMonth === undefined ? false : _ref$endOfMonth,
      _ref$format = _ref.format,
      format = _ref$format === undefined ? 'DD MMMM YYYY' : _ref$format;

  if (!date) {
    return '-';
  }

  var momentDate = _moment2.default.utc(date);

  if (startOfMonth) {
    momentDate = momentDate.startOf('month');
  }
  if (endOfMonth) {
    momentDate = momentDate.endOf('month');
  }

  return momentDate.format(format).toUpperCase();
}

function getDateCalendar(date) {
  return {
    weekday: date.weekday(),
    date: date,
    day: date.format('DD'),
    bankHoliday: !!hd.isHoliday(date.toDate())
  };
}

function generateMonth(date) {
  if (!date) {
    return Array(30).fill().map(function (e, i) {
      return {
        weekday: 0,
        date: null,
        day: i + 1,
        bankHoliday: false
      };
    });
  }

  var startDate = _moment2.default.utc(date).startOf('month');
  var endDate = _moment2.default.utc(date).endOf('month');
  var endDay = parseInt(endDate.format('DD'), 10);

  var month = [getDateCalendar(startDate)];
  for (var i = 1; i < endDay; i++) {
    var today = month[i - 1].date.clone().add('day', 1);

    month[i] = getDateCalendar(today);
  }

  return month;
}

function getJobCategory(category) {
  var catLabel = '-';
  switch (category) {
    default:
    case 'prive_cadre':
      catLabel = 'SALARIÉ - CADRE';
      break;
    case 'prive_non_cadre':
      catLabel = 'SALARIÉ';
      break;
    case 'public_titulaire_etat':
      catLabel = "TITULAIRE D'ÉTAT";
      break;
    case 'public_non_titulaire':
      catLabel = 'NON-TITULAIRE DE LA FONCTION PUBLIQUE';
      break;
  }
  return catLabel;
}

var Payslip = function Payslip(_ref2) {
  var company = _ref2.company,
      employee = _ref2.employee,
      job = _ref2.job,
      payslip = _ref2.payslip,
      light = _ref2.light,
      _ref2$payslip$gouv_js = _ref2.payslip.gouv_json.values,
      gouv_json = _ref2$payslip$gouv_js === undefined ? {} : _ref2$payslip$gouv_js;

  var _getDayOff = getDayOff(job.start_date, payslip.payslip_date),
      cpPrevious = _getDayOff.cpPrevious,
      cp = _getDayOff.cp;

  var FAKE_DATA = {
    assietteTrancheBSalarie: 46.33,
    complementaireTrancheBSalarie: 5.02,
    complementaireTrancheBEmployeur: 8.2,
    prevoyanceTrancheBSalarie: 0.66,
    prevoyanceTrancheBEmployeur: 0.66,
    horaires: 151.67,
    tepaEmployeur: 26,
    formationProEmployeur: 19.17,
    agffTrancheBEmployeur: 0.84,
    tauxHoraire: job.salary ? (job.salary / 151.67).toFixed(4) : '-'
  };
  FAKE_DATA.salaryB = job.salary ? (job.salary - FAKE_DATA.assietteTrancheBSalarie).toFixed(2) : '-';

  return _react2.default.createElement(
    'section',
    { className: 'payslip__container' },
    _react2.default.createElement(
      'section',
      { className: 'title u-mb' },
      _react2.default.createElement(
        'h3',
        null,
        'BULLETIN DE PAIE'
      ),
      _react2.default.createElement(
        'h4',
        null,
        'EN EUROS'
      )
    ),
    _react2.default.createElement(
      'section',
      { className: 'section__full u-mb' },
      _react2.default.createElement(
        'div',
        { className: 'column container__border column__company u-c u-pl' },
        _react2.default.createElement(
          'div',
          null,
          company.name || '-'
        ),
        _react2.default.createElement(
          'div',
          null,
          company.address_street || '-'
        ),
        _react2.default.createElement(
          'div',
          null,
          company.address_zip || '-',
          ' ',
          company.address_city || '-'
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'column column__period' },
        _react2.default.createElement(
          'ul',
          null,
          _react2.default.createElement(
            'li',
            { className: 'row__period' },
            _react2.default.createElement(
              'span',
              null,
              'DEBUT DE PE\u0301RIODE'
            ),
            _react2.default.createElement(
              'span',
              null,
              formatDate({ date: payslip.payslip_date })
            )
          ),
          _react2.default.createElement(
            'li',
            { className: 'row__period' },
            _react2.default.createElement(
              'span',
              null,
              'FIN DE PE\u0301RIODE'
            ),
            _react2.default.createElement(
              'span',
              null,
              formatDate({ date: payslip.payslip_date, endOfMonth: true })
            )
          ),
          _react2.default.createElement(
            'li',
            { className: 'row__period' },
            _react2.default.createElement(
              'span',
              null,
              'DE\u0301BUT DU CONTRAT'
            ),
            _react2.default.createElement(
              'span',
              null,
              formatDate({ date: job.start_date })
            )
          ),
          _react2.default.createElement(
            'li',
            { className: 'row__period' },
            _react2.default.createElement(
              'span',
              null,
              'DATE D\'ANCIENNETE\u0301'
            ),
            _react2.default.createElement(
              'span',
              null,
              formatDate({ date: job.start_date })
            )
          ),
          _react2.default.createElement(
            'li',
            { className: 'row__period' },
            _react2.default.createElement(
              'span',
              null,
              'N\xB0 DE SE\u0301CURITE\u0301 SOCIALE'
            ),
            _react2.default.createElement(
              'span',
              null,
              employee.ssn || '-'
            )
          )
        )
      )
    ),
    _react2.default.createElement(
      'section',
      { className: 'section__full u-mb' },
      _react2.default.createElement(
        'div',
        { className: 'column' },
        _react2.default.createElement(
          'ul',
          null,
          _react2.default.createElement(
            'li',
            null,
            'N\xB0 SIRET: ',
            company.siren || '-'
          ),
          _react2.default.createElement(
            'li',
            null,
            'N\xB0 APE: ',
            company.naf || '-'
          ),
          _react2.default.createElement(
            'li',
            null,
            'CONVENTION COLLECTIVE: -'
          ),
          _react2.default.createElement(
            'li',
            null,
            'LIEU DE PAIEMENT DES COTISATIONS SOCIALES :',
            _react2.default.createElement('br', null),
            'URSSAF ILE-DE-FRANCE'
          )
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'column container__border column__employee u-c u-pl' },
        _react2.default.createElement(
          'div',
          null,
          employee.first_name || '-',
          ' ',
          employee.last_name || '-'
        ),
        _react2.default.createElement(
          'div',
          null,
          employee.address_street || '-'
        ),
        _react2.default.createElement(
          'div',
          null,
          employee.address_zip || '-',
          ' ',
          employee.address_city || '-'
        )
      )
    ),
    _react2.default.createElement(
      'section',
      { className: 'section__full container__border u-mb job__container' },
      _react2.default.createElement(
        'div',
        { className: 'column u-rb' },
        _react2.default.createElement(
          'ul',
          null,
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'CLASSIFICATION:'
            ),
            _react2.default.createElement(
              'span',
              null,
              getJobCategory(job.category)
            )
          ),
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'CATEGORIE:'
            ),
            _react2.default.createElement(
              'span',
              null,
              job.coefficient || '-'
            )
          ),
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'EMPLOI:'
            ),
            _react2.default.createElement(
              'span',
              null,
              (job.label || '-').toUpperCase()
            )
          )
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'column u-rb' },
        _react2.default.createElement(
          'ul',
          null,
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'MINIMUM COEFFICIENT:'
            ),
            _react2.default.createElement(
              'span',
              null,
              getValue(job.salary ? job.salary * 2 / 3 : null)
            )
          ),
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'RE\u0301MUNE\u0301RATION TOTALE DU MOIS:'
            ),
            _react2.default.createElement(
              'span',
              null,
              getValue(job.salary)
            )
          )
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'column' },
        _react2.default.createElement(
          'ul',
          null,
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'SALAIRE DE BASE:'
            ),
            _react2.default.createElement(
              'span',
              null,
              getValue(job.salary)
            )
          ),
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'DUREE MENSUELLE:'
            ),
            _react2.default.createElement(
              'span',
              null,
              FAKE_DATA.horaires,
              ' h'
            )
          ),
          _react2.default.createElement(
            'li',
            null,
            _react2.default.createElement(
              'span',
              null,
              'TAUX HORAIRE:'
            ),
            _react2.default.createElement(
              'span',
              null,
              FAKE_DATA.tauxHoraire
            )
          )
        )
      )
    ),
    light ? _react2.default.createElement('img', {
      alt: 'Payslip placeholder',
      src: '/static/img/placeholder.png',
      className: 'img-placeholder'
    }) : _react2.default.createElement(
      'section',
      { className: 'section__full u-mb' },
      _react2.default.createElement(
        'table',
        { className: 'container__border u-mr flex flex__one table__main' },
        _react2.default.createElement(
          'tbody',
          null,
          _react2.default.createElement(
            'tr',
            { className: 'row__first row__border' },
            _react2.default.createElement(
              'th',
              null,
              'DE\u0301SIGNATION'
            ),
            _react2.default.createElement(
              'th',
              null,
              'NOMBRE OU BASE'
            ),
            _react2.default.createElement(
              'th',
              null,
              'TAUX OU %'
            ),
            _react2.default.createElement(
              'th',
              null,
              'MONTANT A\u0300 AJOUTER'
            ),
            _react2.default.createElement(
              'th',
              null,
              'MONTANT A\u0300 DE\u0301DUIRE'
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'row__padding' },
            _react2.default.createElement(
              'td',
              null,
              'Salaire de base'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.horaires
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.tauxHoraire || '-'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Heures supple\u0301mentaires 25%'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Absence non re\u0301mune\u0301re\u0301e'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'Salaire brut (1)'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              _react2.default.createElement(
                'strong',
                null,
                getValue(job.salary)
              )
            ),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'URSSAF'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Assurance maladie'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.750'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.mmid_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Vieillesse plafonne\u0301e'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.salaryB
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '6.900'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.vieillesse_plafonnee_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Vieillesse de\u0301plafonne\u0301e'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.350'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.vieillesse_deplafonnee_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Allocations familiales'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Accident du travail'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'FNAL'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.salaryB
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Solidarite\u0301 autonomie'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Contribution au dialogue social'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'CSG de\u0301ductible'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '5.100'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.csg_deductible_salaire)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'CSG non de\u0301ductible'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '2.400'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.assiette_csg_non_abattue)
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              null,
              'CRDS non de\u0301ductible'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.500'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.crds_salaire)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'Re\u0301duction de cotisations'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              null,
              'De\u0301duction forfaitaire loi TEPA'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '16.92'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'Assurance Cho\u0302mage'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Cho\u0302mage'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '2.400'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.chomage_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              null,
              'AGS'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'Retraite comple\u0301mentaire'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'AGFF | Tranche A'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.salaryB
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.800'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.agff_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'AGFF | Tranche B'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.assietteTrancheBSalarie
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.900'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.penibilite)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Comple\u0301mentaire | Tranche A'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.salaryB
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '3.100'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.arrco_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Comple\u0301mentaire | Tranche B'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.assietteTrancheBSalarie
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '7.800'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.complementaireTrancheBSalarie
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'APEC'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.024'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.apec_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'CET'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.130'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.cotisation_exceptionnelle_temporaire_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              null,
              'GMP'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.agirc_gmp_assiette)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '7.800'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.agirc_salarie, gouv_json.agirc_gmp_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'Pre\u0301voyance & Mutuelle'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Comple\u0301mentaire Sante\u0301 Tranche A'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.salaryB
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.590'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.complementaire_sante_salarie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Pre\u0301voyance Tranche A'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.salaryB
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              null,
              'Pre\u0301voyance Tranche B'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.assietteTrancheBSalarie
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '1.025'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              FAKE_DATA.prevoyanceTrancheBSalarie
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'Autres cotisations patronales'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'Taxe d\'apprentissage'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              null,
              'Formation professionnelle'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(job.salary)
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'row__padding' },
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'COTISATIONS SALARIALES (4)'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              _react2.default.createElement(
                'strong',
                null,
                getValue(gouv_json.mmid_salarie, gouv_json.vieillesse_plafonnee_salarie, gouv_json.vieillesse_deplafonnee_salarie, gouv_json.csg_deductible_salaire, gouv_json.assiette_csg_non_abattue, gouv_json.crds_salaire, gouv_json.chomage_salarie, gouv_json.agff_salarie, gouv_json.penibilite, gouv_json.arrco_salarie, FAKE_DATA.complementaireTrancheBSalarie, gouv_json.apec_salarie, gouv_json.cotisation_exceptionnelle_temporaire_salarie, gouv_json.agirc_salarie, gouv_json.agirc_gmp_salarie, gouv_json.complementaire_sante_salarie, FAKE_DATA.prevoyanceTrancheBSalarie)
              )
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              _react2.default.createElement(
                'strong',
                null,
                'COTISATIONS PATRONALES'
              )
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          )
        )
      ),
      _react2.default.createElement(
        'table',
        { className: 'container__border u-mr flex flex__shrink' },
        _react2.default.createElement(
          'tbody',
          null,
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'th',
              { colSpan: '2' },
              'COTISATIONS PATRONALES'
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'row__border' },
            _react2.default.createElement(
              'th',
              null,
              'TAUX OU %'
            ),
            _react2.default.createElement(
              'th',
              null,
              'MONTANT'
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '12.840'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.mmid_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '8.550'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.vieillesse_plafonnee_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '1.850'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.vieillesse_deplafonnee_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '3.450'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.famille)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.taux_accident_travail)
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.accident_du_travail)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.100'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.fnal)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.300'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.contribution_solidarite_autonomie)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.016'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.financement_organisations_syndicales)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '-1.500'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '-',
              getValue(FAKE_DATA.tepaEmployeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '4.000'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.chomage_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.250'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.ags)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '1.200'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.agff_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '1.300'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(FAKE_DATA.agffTrancheBEmployeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '4.650'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.arrco_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '12.750'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(FAKE_DATA.complementaireTrancheBEmployeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.036'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.apec_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.220'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.cotisation_exceptionnelle_temporaire_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '12.750'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.agirc_employeur, gouv_json.agirc_gmp_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.590'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.complementaire_sante_employeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '1.500'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.prevoyance_obligatoire_cadre)
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '1.025'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(FAKE_DATA.prevoyanceTrancheBEmployeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.680'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(gouv_json.taxe_apprentissage)
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'section__last' },
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              '0.006'
            ),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(FAKE_DATA.formationProEmployeur)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement('td', null)
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              getValue(getValue(gouv_json.mmid_employeur, gouv_json.vieillesse_plafonnee_employeur, gouv_json.vieillesse_deplafonnee_employeur, gouv_json.famille, gouv_json.accident_du_travail, gouv_json.fnal, gouv_json.contribution_solidarite_autonomie, gouv_json.financement_organisations_syndicales, gouv_json.chomage_employeur, gouv_json.ags, gouv_json.agff_employeur, FAKE_DATA.agffTrancheBEmployeur, gouv_json.arrco_employeur, FAKE_DATA.complementaireTrancheBEmployeur, gouv_json.apec_employeur, gouv_json.cotisation_exceptionnelle_temporaire_employeur, gouv_json.agirc_employeur, gouv_json.agirc_gmp_employeur, gouv_json.complementaire_sante_employeur, gouv_json.prevoyance_obligatoire_cadre, FAKE_DATA.prevoyanceTrancheBEmployeur, gouv_json.taxe_apprentissage, FAKE_DATA.formationProEmployeur) - FAKE_DATA.tepaEmployeur)
            )
          )
        )
      ),
      _react2.default.createElement(
        'table',
        { className: 'container__border' },
        _react2.default.createElement(
          'tbody',
          null,
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'th',
              { colSpan: '2' },
              'CALENDRIER'
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'th',
              { colSpan: '2' },
              formatDate({
                date: payslip.payslip_date,
                startOfMonth: true,
                format: 'DD/MM/YYYY'
              }),
              ' ',
              'AU',
              ' ',
              formatDate({
                date: payslip.payslip_date,
                endOfMonth: true,
                format: 'DD/MM/YYYY'
              })
            )
          ),
          _react2.default.createElement(
            'tr',
            { className: 'row__border' },
            _react2.default.createElement(
              'th',
              null,
              'JOUR'
            ),
            _react2.default.createElement(
              'th',
              null,
              'INCIDENT'
            )
          ),
          generateMonth(payslip.payslip_date).map(function (d, i) {
            return _react2.default.createElement(
              'tr',
              { className: 'row__calendar', key: i },
              _react2.default.createElement(
                'td',
                null,
                _react2.default.createElement(
                  'span',
                  { className: 'row__calendar_day' },
                  _moment2.default.weekdaysShort()[d.weekday]
                ),
                ' ',
                d.day
              ),
              _react2.default.createElement(
                'td',
                null,
                d.bankHoliday ? 'JF' : ''
              )
            );
          })
        )
      )
    ),
    _react2.default.createElement(
      'section',
      { className: 'section__full u-mb' },
      _react2.default.createElement(
        'table',
        { className: 'container__border u-mr revenu__container' },
        _react2.default.createElement(
          'tbody',
          null,
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'th',
              null,
              'REVENUS EN EUROS'
            ),
            _react2.default.createElement(
              'th',
              null,
              'DU MOIS'
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'BRUT IMPOTS DONT AVANTAGES NATURE'
            ),
            _react2.default.createElement(
              'td',
              null,
              getValue(job.salary)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'REVENU IMPOSABLE'
            ),
            _react2.default.createElement(
              'td',
              null,
              getValue(gouv_json.salaire_imposable)
            )
          )
        )
      ),
      _react2.default.createElement(
        'table',
        { className: 'container__border paid__container' },
        _react2.default.createElement(
          'tbody',
          null,
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'th',
              null,
              'NET A\u0300 PAYER ',
              _react2.default.createElement('br', null),
              '1+2-3+4',
              _react2.default.createElement('br', null),
              'EN EUROS'
            ),
            _react2.default.createElement(
              'th',
              null,
              'VIREMENT'
            ),
            _react2.default.createElement(
              'th',
              { className: 'cell__value' },
              getValue(gouv_json.salaire_net_a_payer)
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'DATE DE PAIEMENT'
            ),
            _react2.default.createElement('td', null),
            _react2.default.createElement(
              'td',
              { className: 'cell__value' },
              formatDate({ date: payslip.payslip_date, endOfMonth: true })
            )
          )
        )
      ),
      light ? null : _react2.default.createElement(
        'table',
        { className: 'container__border container__bank-holiday' },
        _react2.default.createElement(
          'tbody',
          null,
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              { className: 'u-p' },
              _react2.default.createElement(
                'strong',
                null,
                'JF'
              ),
              ' JOUR FE\u0301RIE\u0301'
            )
          )
        )
      )
    ),
    _react2.default.createElement(
      'section',
      { className: 'section__full' },
      _react2.default.createElement(
        'table',
        { className: 'container__border u-mr' },
        _react2.default.createElement(
          'tbody',
          null,
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement('th', null),
            _react2.default.createElement(
              'th',
              null,
              'ACQUIS'
            ),
            _react2.default.createElement(
              'th',
              null,
              'PRIS'
            ),
            _react2.default.createElement(
              'th',
              null,
              'SOLDE'
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'CP N-1'
            ),
            _react2.default.createElement(
              'td',
              null,
              cpPrevious
            ),
            _react2.default.createElement(
              'td',
              null,
              '0.00'
            ),
            _react2.default.createElement(
              'td',
              null,
              cpPrevious
            )
          ),
          _react2.default.createElement(
            'tr',
            null,
            _react2.default.createElement(
              'td',
              null,
              'CP N'
            ),
            _react2.default.createElement(
              'td',
              null,
              cp
            ),
            _react2.default.createElement(
              'td',
              null,
              '0.00'
            ),
            _react2.default.createElement(
              'td',
              null,
              cp
            )
          )
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'flex flex__one container__border comment__container' },
        _react2.default.createElement(
          'strong',
          null,
          'COMMENTAIRES'
        )
      )
    ),
    _react2.default.createElement(
      'section',
      { className: 'payslip__footer' },
      'Nous vous recommandons de conserver votre bulletin de paie, sans limitation de dure\u0301e.'
    )
  );
};

Payslip.propTypes = {
  company: _propTypes2.default.shape({
    name: _propTypes2.default.string,
    address_street: _propTypes2.default.string,
    address_zip: _propTypes2.default.string,
    address_city: _propTypes2.default.string,
    siren: _propTypes2.default.string,
    urssaf: _propTypes2.default.string,
    naf: _propTypes2.default.string
  }),
  employee: _propTypes2.default.shape({
    first_name: _propTypes2.default.string,
    last_name: _propTypes2.default.string,
    ssn: _propTypes2.default.string,
    address_street: _propTypes2.default.string,
    address_zip: _propTypes2.default.string,
    address_city: _propTypes2.default.string
  }),
  job: _propTypes2.default.shape({
    label: _propTypes2.default.string,
    category: _propTypes2.default.string,
    coefficient: _propTypes2.default.string,
    start_date: _propTypes2.default.string,
    salary: _propTypes2.default.string
  }),
  payslip: _propTypes2.default.shape({
    payslip_date: _propTypes2.default.string,
    gouv_json: _propTypes2.default.shape({}),
    company_id: _propTypes2.default.string,
    employee_id: _propTypes2.default.string,
    job_id: _propTypes2.default.string,
    user_id: _propTypes2.default.string
  }),
  light: _propTypes2.default.bool
};

var cYear = new Date().getUTCFullYear();
Payslip.defaultProps = {
  company: {
    name: '',
    address_street: '',
    address_zip: '',
    address_city: '',
    siren: '',
    urssaf: '',
    naf: ''
  },
  employee: {
    first_name: '',
    last_name: '',
    ssn: '',
    address_street: '',
    address_zip: '',
    address_city: ''
  },
  job: {
    label: '',
    category: 'prive_cadre',
    coefficient: '115',
    start_date: new Date(Date.UTC(cYear, 0, 1)).toISOString(),
    salary: ''
  },
  payslip: {
    payslip_date: new Date(Date.UTC(cYear, 0, 1)).toISOString(),
    gouv_json: {},
    company_id: '',
    employee_id: '',
    job_id: '',
    user_id: ''
  },
  light: false
};

var PayslipPropTypes = exports.PayslipPropTypes = Payslip.propTypes;

exports.default = Payslip;